import org.springframework.orm.hibernate3.annotation.AnnotationSessionFactoryBean
import org.springframework.orm.hibernate3.HibernateTransactionManager
import org.apache.commons.dbcp.BasicDataSource
import grails.plugins.wordpress.model.Category
import grails.plugins.wordpress.model.Comment
import grails.plugins.wordpress.model.Page
import grails.plugins.wordpress.model.Post
import grails.plugins.wordpress.model.Tag
import grails.plugins.wordpress.model.User
import grails.util.Environment

class WordpressGrailsPlugin {
    // the plugin version
    def version = "0.2.3"
    // the version or versions of Grails the plugin is designed for
    def grailsVersion = "1.2.2 > *"
    // the other plugins this plugin depends on
    def dependsOn = [hibernate:'1.2.2 > *', quartz:'0.4.1']
    // resources that are excluded from plugin packaging
    def pluginExcludes = [
            "grails-app/views/error.gsp"
    ]

    // TODO Fill in these fields
    def author = "Luis Arias"
    def authorEmail = "luis.arias@pilango.com"
    def title = "Wordpress Plugin"
    def description = '''\\
The Wordpress plugin provides tags for pulling content from wordpress for display in grails.
'''

    // URL to the plugin's documentation
    def documentation = "http://grails.org/Wordpress+Plugin"

    def doWithSpring = {
        xmlns tx:"http://www.springframework.org/schema/tx"
        tx.'annotation-driven'()
        wordpressDataSource(BasicDataSource) {
            driverClassName = "org.hsqldb.jdbcDriver"
            url = "jdbc:hsqldb:mem:wordpressDb"
            username = "sa"
            password = ""
        }
        wordpressSessionFactory(AnnotationSessionFactoryBean) {
            dataSource = wordpressDataSource
            hibernateProperties = [
                "hibernate.dialect" : "org.hibernate.dialect.HSQLDialect",
                "hibernate.connection.pool_size" : "10",
                "hibernate.connection.autocommit" : "false",
                "hibernate.cache.provider_class" : "org.hibernate.cache.NoCacheProvider",
                "hibernate.hbm2ddl.auto" : "create-drop",
                "hibernate.show_sql" : "false",
                "hibernate.transaction.factory_class" : "org.hibernate.transaction.JDBCTransactionFactory",
                "hibernate.current_session_context_class" : "thread"
            ]
            annotatedClasses = [
                Category,
                Comment,
                Page,
                Post,
                Tag,
                User
            ]
        }
        wordpressTransactionManager(HibernateTransactionManager) {
            sessionFactory = wordpressSessionFactory
            dataSource = wordpressDataSource
        }

        if (Environment.current.name == 'wordpress') {
            transactionManager(HibernateTransactionManager) {
                sessionFactory = wordpressSessionFactory
                dataSource = wordpressDataSource
            }
        }
    }

    def doWithApplicationContext = { applicationContext ->

    }

    def doWithWebDescriptor = { xml ->
        // TODO Implement additions to web.xml (optional)
    }

    def doWithDynamicMethods = { ctx ->
        // TODO Implement registering dynamic methods to classes (optional)
    }

    def onChange = { event ->
        // TODO Implement code that is executed when any artefact that this plugin is
        // watching is modified and reloaded. The event contains: event.source,
        // event.application, event.manager, event.ctx, and event.plugin.
    }

    def onConfigChange = { event ->
        // TODO Implement code that is executed when the project configuration changes.
        // The event is the same as for 'onChange'.
    }
}
