import groovy.net.xmlrpc.XMLRPCServerProxy
import net.sf.ehcache.Element

class WordpressService {

    boolean transactional = false

    def cacheService

    String url
    int blogId
    String username
    String password

    void init(String url, int blogId, String username, String password) {
        this.url = url
        this.blogId = blogId
        this.username = username
        this.password = password

        updateRecentPostsCache()
        updatePagesCache()
        updateCategoriesCache()
    }

    void updateRecentPostsCache() {
        def serverProxy = new XMLRPCServerProxy(url, true)
        def posts = serverProxy."metaWeblog.getRecentPosts"(blogId, username, password, 1)
        posts = serverProxy."metaWeblog.getRecentPosts"(blogId, username, password, posts[0].postid)
        synchronized (cacheService) {
            cacheService.setRecentPosts(posts)
        }
    }

    void updatePagesCache() {
        def serverProxy = new XMLRPCServerProxy(url, true)
        def pages = serverProxy."wp.getPageList"(blogId, username, password)
        int maxid = pages.collect { it.page_id.toInteger() }.max()
        pages = serverProxy."wp.getPages"(blogId, username, password, maxid)
        synchronized (cacheService) {
            cacheService.setPages(pages)
        }
    }

    void updateCategoriesCache() {
        def serverProxy = new XMLRPCServerProxy(url, true)
        def categories = serverProxy."wp.getCategories"(blogId, username, password)
        synchronized (cacheService) {
            cacheService.setCategories(categories)
        }
    }

    def getCategories() {
        cacheService.categories.sort {
            it.categoryName
        }
    }

    def getPage(String id) {
        def page = cacheService.getPage(id)
        if (!page) {
            log.info "Page ${id} not found in cache, attempting to retrieve"
            def serverProxy = new XMLRPCServerProxy(url, true)
            try {
                synchronized (cacheService) {
                    page = serverProxy."wp.getPage"(blogId, id, username, password)
                    cacheService.putPage(page)
                }
            } catch (Exception e) {
                log.info "Could not get page ${id}", e
            }
        }
        return page
    }

    def getRecentPosts(int count, String status = 'publish') {
        cacheService.getRecentPosts(count, status)
    }

    def getPost(String id) {
        def post = cacheService.getPost(id)
        if (!post) {
            def serverProxy = new XMLRPCServerProxy(url, true)
            try {
                synchronized (cacheService) {
                    post = serverProxy."metaWeblog.getPost"(id, username, password)
                    cacheService.putPost(post)
                }
            } catch (Exception e) {
                log.info "Could not get post ${id}", e
            }
        }
        return post
    }
}
