import groovy.net.xmlrpc.XMLRPCServerProxy
import net.sf.ehcache.Element

class WordpressService {

    boolean transactional = false

    def wordpressCache

    String url
    int blogId
    String username
    String password

    def recentPostIds = []

    void init(String url, int blogId, String username, String password) {
        this.url = url
        this.blogId = blogId
        this.username = username
        this.password = password

        updateRecentPostsCache()
    }

    void updateRecentPostsCache() {
        def serverProxy = new XMLRPCServerProxy(url, true)
        def posts = serverProxy."metaWeblog.getRecentPosts"(blogId, username, password, 1)
        posts = serverProxy."metaWeblog.getRecentPosts"(blogId, username, password, posts[0].postid)
        recentPostIds = []
        posts.each { post ->
            recentPostIds << post.postid
            wordpressCache.put(new Element(post.postid, post))
        }
    }

    def getCategories() {
        def serverProxy = new XMLRPCServerProxy(url, true)
        def categories = serverProxy."wp.getCategories"(blogId, username, password)
        categories.sort {
            it.categoryName
        }
    }

    def getPage(String id) {
        def page = wordpressCache.get(id)?.value
        if (!page) {
            def serverProxy = new XMLRPCServerProxy(url, true)
            page = serverProxy."wp.getPage"(blogId, id, username, password)
            wordpressCache.put(new Element(id, page))
        }
        return page
    }

    def getRecentPosts(int count, String status = 'publish') {
        def serverProxy = new XMLRPCServerProxy(url, true)
        if (!recentPostIds || !wordpressCache.get(recentPostIds[0])) {
            updateRecentPostsCache()
        }
        def posts = []
        recentPostIds.each { postid ->
            if (posts.size() < count) {
                def post = wordpressCache.get(postid).value
                if (!status || status == post.post_status) {
                    posts << post
                }
            }
        }
        posts
    }

    def getPost(String id) {
        def page = wordpressCache.get(id)?.value
        if (!page) {
            def serverProxy = new XMLRPCServerProxy(url, true)
            page = serverProxy."metaWeblog.getPost"(id, username, password)
            wordpressCache.put(new Element(id, page))
        }
        return page
    }
}
