package grails.plugins.wordpress

class WordpressTagLib {
    static namespace = 'wordpress'

    def groovyPagesTemplateEngine
    def pluginManager
    def wordpressService

    private def boolean checkIfTemplateExists(template, attrs) {
        if(!groovyPagesTemplateEngine) throw new IllegalStateException("Property [groovyPagesTemplateEngine] must be set!")

        def engine = groovyPagesTemplateEngine
        def uri = grailsAttributes.getTemplateUri(template,request)
        def contextPath = attrs.contextPath ? attrs.contextPath : ""

        if(attrs.plugin) {
            def plugin = pluginManager?.getGrailsPlugin(attrs.plugin)
            if(plugin) contextPath = plugin.getPluginPath()
        }

        def r = engine.getResourceForUri("${contextPath}${uri}")
        if(!r.exists()) r = engine.getResourceForUri("${contextPath}/grails-app/views/${uri}")
        return r.exists()
    }
    
    def categories = {attrs, body ->
        try {
            def categories = wordpressService.getCategories()
            if (checkIfTemplateExists('/wordpress/categories', attrs)) {
                out << render(template:'/wordpress/categories', model:[categories:categories])
            } else {
                out << render(template:'/wordpress/categories', plugin:'wordpress', model:[categories:categories])
            }
        } catch (Exception e) {
            log.error "Cannot render wordpress categories tag", e
        }
    }

    def page = {attrs, body ->
        if (attrs.id) {
            try {
                def page = wordpressService.getPage(attrs.id as Long)
                if (checkIfTemplateExists('/wordpress/page', attrs)) {
                    out << render(template:'/wordpress/page', model:[page:page])
                } else {
                    out << render(template:'/wordpress/page', plugin:'wordpress', model:[page:page])
                }
            } catch (Exception e) {
                log.error "Error rendering the wordpress page tag", e
            }
        }
    }

    def recentPosts = {attrs, body ->
        if (attrs.count && attrs.count?.isNumber()) {
            def count = attrs.count as Integer
            def status = attrs.status ?: 'publish'
            if (!(status ==~ /(publish|draft|private|pending)/)) {
                throwTagError("Tag [recentPosts] may have a [status] attribute that is either 'publish', 'draft', 'private' or 'pending'.")
            }
            try {
                def posts = wordpressService.getRecentPosts([status:status, max:count])
                if (checkIfTemplateExists('/wordpress/recentposts', attrs)) {
                    out << render(template:'/wordpress/recentposts', model:[posts:posts])
                } else {
                    out << render(template:'/wordpress/recentposts', plugin:'wordpress', model:[posts:posts])
                }
            } catch (Exception e) {
                log.error "Error rendering the wordpress recentPosts tag", e
            }
        } else {
            throwTagError("Tag [recentPosts] must have a non-zero, integer [count] attribute.")
        }
    }
}
