package grails.plugins.wordpress

import grails.test.*

class WordpressServiceTests extends GrailsUnitTestCase {

    def wordpressService

    boolean transactional = false

    static final def EMPTY = []

    void testUpdateCache() {
        wordpressService.updateCache()
        assertTrue true
    }

    void testUpdateCacheTwice() {
        wordpressService.updateCache()
        def firstCount = wordpressService.getPostCount()
        wordpressService.updateCache()
        assertEquals firstCount, wordpressService.getPostCount()
    }

    void testGetUsers() {
        assertNotNull wordpressService.getUsers()
    }

    void testGetUsersCalledTwice() {
        assertEquals "${wordpressService.getUsers(nocache:true)}", "${wordpressService.getUsers(nocache:true)}"
    }

    void testGetPost() {
        assertNotNull wordpressService.getPost(1, [nocache:true])
    }

    void testGetRecentPostsNoCache() {
        def posts = wordpressService.getRecentPosts(max:1, nocache:true)
        assertNotNull posts
        assertEquals 1, posts.size()
    }

    void testGetPage() {
        assertNotNull wordpressService.getPage(2, [nocache:true])
    }

    void testGetPageParent() {
        def page = wordpressService.getPage(7, [nocache:true])
        assertNotNull page
        assertNotNull page.parent
    }

    void testGetCategories() {
        assertNotNull wordpressService.getCategories(nocache:true)
    }

    void testGetTags() {
        assertNotNull wordpressService.getTags(nocache:true)
    }

    void testGetComments() {
        assertNotNull wordpressService.getComments(nocache:true, postId:1)
    }

    void testGetPostsInCategory() {
        def posts = wordpressService.getRecentPostsInCategory('Functional Tests')
        assertTrue posts.size() > 0
        posts.each {
            assertTrue it.categories.size() > 0
            assertNotNull it.categories.find {it.name == 'Functional Tests'}
        }
    }

    void testGetPostCountInCategory() {
        assertEquals 1, wordpressService.getPostCountInCategory('Functional Tests')
    }

    void testGetPostsWithTag() {
        def posts = wordpressService.getRecentPostsWithTag('silly')
        assertTrue posts.size() > 0
    }

    void testGetPostsWithTagInCategory() {
        def posts = wordpressService.getRecentPostsWithTagInCategory('silly', 'Functional Tests')
        assertTrue posts.size() > 0
        posts.each {
            assertTrue it.categories.size() > 0
            assertNotNull it.categories.find {it.name == 'Functional Tests'}
            assertTrue it.tags.size() > 0
            assertNotNull it.tags.find {it.name == 'silly'}
        }
    }

    void testGetPostsUnknownTag() {
        def posts = wordpressService.getRecentPostsWithTag('This tag does not exist')
        assertTrue posts.size() == 0
    }

    void testGetPostsUnknownCategory() {
        def posts = wordpressService.getRecentPostsInCategory('This category does not exist')
        assertTrue posts.size() == 0
    }

    void testGetPostsUnknownTagAndCategory() {
        def posts = wordpressService.getRecentPostsWithTagInCategory('This tag does not exist', 'This category does not exist')
        assertTrue posts.size() == 0
    }

}
